@@ -1,6 +1,6 @@
 package SPVM::Digest::SHA;
 
-our $VERSION = "0.061";
+our $VERSION = "0.061001";
 
 1;
 
@@ -40,19 +40,19 @@ Object Oriented Programming:
 
 =head2 sha1
 
-  static method sha1 : string ($data : string)
+C<static method sha1 : string ($data : string);>
 
 Receive the input date and return its SHA-1 digest encoded as a binary string.
 
 =head2 sha1_hex
 
-  static method sha1_hex : string ($data : string)
+C<static method sha1_hex : string ($data : string);>
 
 Receive the input date and return its SHA-1 digest encoded as a hexadecimal string.
 
 =head2 sha1_base64
 
-  static method sha1_base64 : string ($data : string)
+C<static method sha1_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-1 digest encoded as a Base64 string.
 
@@ -60,19 +60,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha224
 
-  static method sha224 : string ($data : string)
+C<static method sha224 : string ($data : string);>
 
 Receive the input date and return its SHA-224 digest encoded as a binary string.
 
 =head2 sha224_hex
 
-  static method sha224_hex : string ($data : string)
+C<static method sha224_hex : string ($data : string);>
 
 Receive the input date and return its SHA-224 digest encoded as a hexadecimal string.
 
 =head2 sha224_base64
 
-  static method sha224_base64 : string ($data : string)
+C<static method sha224_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-224 digest encoded as a Base64 string.
 
@@ -80,19 +80,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha256
 
-  static method sha256 : string ($data : string)
+C<static method sha256 : string ($data : string);>
 
 Receive the input date and return its SHA-256 digest encoded as a binary string.
 
 =head2 sha256_hex
 
-  static method sha256_hex : string ($data : string)
+C<static method sha256_hex : string ($data : string);>
 
 Receive the input date and return its SHA-256 digest encoded as a hexadecimal string.
 
 =head2 sha256_base64
 
-  static method sha256_base64 : string ($data : string)
+C<static method sha256_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-256 digest encoded as a Base64 string.
 
@@ -100,19 +100,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha384
 
-  static method sha384 : string ($data : string)
+C<static method sha384 : string ($data : string);>
 
 Receive the input date and return its SHA-384 digest encoded as a binary string.
 
 =head2 sha384_hex
 
-  static method sha384_hex : string ($data : string)
+C<static method sha384_hex : string ($data : string);>
 
 Receive the input date and return its SHA-384 digest encoded as a hexadecimal string.
 
 =head2 sha384_base64
 
-  static method sha384_base64 : string ($data : string)
+C<static method sha384_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-384 digest encoded as a Base64 string.
 
@@ -120,19 +120,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha512
 
-  static method sha512 : string ($data : string)
+C<static method sha512 : string ($data : string);>
 
 Receive the input date and return its SHA-512 digest encoded as a binary string.
 
 =head2 sha512_hex
 
-  static method sha512_hex : string ($data : string)
+C<static method sha512_hex : string ($data : string);>
 
 Receive the input date and return its SHA-512 digest encoded as a hexadecimal string.
 
 =head2 sha512_base64
 
-  static method sha512_base64 : string ($data : string)
+C<static method sha512_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-512 digest encoded as a Base64 string.
 
@@ -140,19 +140,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha512224
 
-  static method sha512224 : string ($data : string)
+C<static method sha512224 : string ($data : string);>
 
 Receive the input date and return its SHA-512/224 digest encoded as a binary string.
 
 =head2 sha512224_hex
 
-  static method sha512224_hex : string ($data : string)
+C<static method sha512224_hex : string ($data : string);>
 
 Receive the input date and return its SHA-512/224 digest encoded as a hexadecimal string.
 
 =head2 sha512224_base64
 
-  static method sha512224_base64 : string ($data : string)
+C<static method sha512224_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-512/224 digest encoded as a Base64 string.
 
@@ -160,19 +160,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 sha512256
 
-  static method sha512256 : string ($data : string)
+C<static method sha512256 : string ($data : string);>
 
 Receive the input date and return its SHA-512/256 digest encoded as a binary string.
 
 =head2 sha512256_hex
 
-  static method sha512256_hex : string ($data : string)
+C<static method sha512256_hex : string ($data : string);>
 
 Receive the input date and return its SHA-512/256 digest encoded as a hexadecimal string.
 
 =head2 sha512256_base64
 
-  static method sha512256_base64 : string ($data : string)
+C<static method sha512256_base64 : string ($data : string);>
 
 Receive the input date and return its SHA-512/256 digest encoded as a Base64 string.
 
@@ -180,19 +180,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha1
 
-  static method hmac_sha1 : string ($data : string, $key : string)
+C<static method hmac_sha1 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-1 digest encoded as a binary string.
 
 =head2 hmac_sha1_hex
 
-  static method hmac_sha1_hex : string ($data : string, $key : string)
+C<static method hmac_sha1_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-1 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha1_base64
 
-  static method hmac_sha1_base64 : string ($data : string, $key : string)
+C<static method hmac_sha1_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-1 digest encoded as a Base64 string.
 
@@ -200,19 +200,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha224
 
-  static method hmac_sha224 : string ($data : string, $key : string)
+C<static method hmac_sha224 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-224 digest encoded as a binary string.
 
 =head2 hmac_sha224_hex
 
-  static method hmac_sha224_hex : string ($data : string, $key : string)
+C<static method hmac_sha224_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-224 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha224_base64
 
-  static method hmac_sha224_base64 : string ($data : string, $key : string)
+C<static method hmac_sha224_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-224 digest encoded as a Base64 string.
 
@@ -220,19 +220,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha256
 
-  static method hmac_sha256 : string ($data : string, $key : string)
+C<static method hmac_sha256 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-256 digest encoded as a binary string.
 
 =head2 hmac_sha256_hex
 
-  static method hmac_sha256_hex : string ($data : string, $key : string)
+C<static method hmac_sha256_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-256 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha256_base64
 
-  static method hmac_sha256_base64 : string ($data : string, $key : string)
+C<static method hmac_sha256_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-256 digest encoded as a Base64 string.
 
@@ -240,19 +240,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha384
 
-  static method hmac_sha384 : string ($data : string, $key : string)
+C<static method hmac_sha384 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-384 digest encoded as a binary string.
 
 =head2 hmac_sha384_hex
 
-  static method hmac_sha384_hex : string ($data : string, $key : string)
+C<static method hmac_sha384_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-384 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha384_base64
 
-  static method hmac_sha384_base64 : string ($data : string, $key : string)
+C<static method hmac_sha384_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-384 digest encoded as a Base64 string.
 
@@ -260,19 +260,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha512
 
-  static method hmac_sha512 : string ($data : string, $key : string)
+C<static method hmac_sha512 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512 digest encoded as a binary string.
 
 =head2 hmac_sha512_hex
 
-  static method hmac_sha512_hex : string ($data : string, $key : string)
+C<static method hmac_sha512_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha512_base64
 
-  static method hmac_sha512_base64 : string ($data : string, $key : string)
+C<static method hmac_sha512_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512 digest encoded as a Base64 string.
 
@@ -280,19 +280,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha512224
 
-  static method hmac_sha512224 : string ($data : string, $key : string)
+C<static method hmac_sha512224 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/224 digest encoded as a binary string.
 
 =head2 hmac_sha512224_hex
 
-  static method hmac_sha512224_hex : string ($data : string, $key : string)
+C<static method hmac_sha512224_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/224 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha512224_base64
 
-  static method hmac_sha512224_base64 : string ($data : string, $key : string)
+C<static method hmac_sha512224_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/224 digest encoded as a Base64 string.
 
@@ -300,19 +300,19 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 hmac_sha512256
 
-  static method hmac_sha512256 : string ($data : string, $key : string)
+C<static method hmac_sha512256 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/256 digest encoded as a binary string.
 
 =head2 hmac_sha512256_hex
 
-  static method hmac_sha512256_hex : string ($data : string, $key : string)
+C<static method hmac_sha512256_hex : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/256 digest encoded as a hexadecimal string.
 
 =head2 hmac_sha512256_base64
 
-  static method hmac_sha512256_base64 : string ($data : string, $key : string)
+C<static method hmac_sha512256_base64 : string ($data : string, $key : string);>
 
 Receive the input date and return its HMAC-SHA-512/256 digest encoded as a Base64 string.
 
@@ -320,7 +320,7 @@ See L<Digest::SHA/"PADDING OF BASE64 DIGESTS"> for details about padding.
 
 =head2 new
 
-  static method new : Digest::SHA ($alg : int)
+C<static method new : L<Digest::SHA|SPVM::Digest::SHA> ($alg : int);>
 
 Returns a new C<Digest::SHA> object.  Allowed values for I<$alg> are 1,
 224, 256, 384, 512, 512224, or 512256.  It's also possible to use
@@ -332,7 +332,7 @@ default.
 
 =head2 hashsize
 
-  method hashsize : int ()
+C<method hashsize : int ();>
 
 Returns the number of digest bits for this object.  The values are
 160, 224, 256, 384, 512, 224, and 256 for SHA-1, SHA-224, SHA-256,
@@ -340,7 +340,7 @@ SHA-384, SHA-512, SHA-512/224 and SHA-512/256, respectively.
 
 =head2 algorithm
 
-  method algorithm : int ()
+C<method algorithm : int ();>
 
 Returns the digest algorithm for this object.  The values are 1,
 224, 256, 384, 512, 512224, and 512256 for SHA-1, SHA-224, SHA-256,
@@ -348,7 +348,7 @@ SHA-384, SHA-512, SHA-512/224, and SHA-512/256, respectively.
 
 =head2 add
 
-  method add : void ($date : string)
+C<method add : void ($date : string);>
 
 Use the input data to
 update the current digest state.  In other words, the following
@@ -359,25 +359,25 @@ statements have the same effect:
 
 =head2 digest
 
-  method digest : string ()
+C<method digest : string ();>
 
 Returns the digest encoded as a binary string.
 
 =head2 b64digest
 
-  method hexdigest : string ()
+C<method hexdigest : string ();>
 
 Returns the digest encoded as a hexadecimal string.
 
 =head2 b64digest
 
-  method b64digest : string ()
+C<method b64digest : string ();>
 
 Returns the digest encoded as a Base64 string.
 
 =head2 
 
-  method clone : Digest::SHA ()
+C<method clone : L<Digest::SHA|SPVM::Digest::SHA> ();>
 
 Returns a duplicate copy of the object.
 
@@ -395,6 +395,10 @@ L<SPVM::Digest::SHA - Github|https://github.com/yuki-kimoto/SPVM-Digest-SHA>
 
 Yuki Kimoto C<kimoto.yuki@gmail.com>
 
+=head1 Contributors
+
+L<Yoshiyuki Itoh|https://github.com/YoshiyukiItoh>
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
